@@ -80,9 +80,11 @@ module BinData
     end
 
     def assign(array)
+      return if self.equal?(array)  # prevent self assignment
       raise ArgumentError, "can't set a nil value for #{debug_name}" if array.nil?
 
-      @element_list = to_storage_formats(array.to_ary)
+      @element_list = []
+      concat(array)
     end
 
     def snapshot
@@ -119,7 +121,17 @@ module BinData
 
     def insert(index, *objs)
       extend_array(index - 1)
-      elements.insert(index, *to_storage_formats(objs))
+      abs_index = (index >= 0) ? index : index + 1 + length
+
+      # insert elements before...
+      new_elements = objs.map { new_element }
+      elements.insert(index, *new_elements)
+
+      # ...assigning values
+      objs.each_with_index do |obj, i|
+        self[abs_index + i] = obj
+      end
+
       self
     end
 
@@ -238,10 +250,6 @@ module BinData
       end
     end
 
-    def to_storage_formats(els)
-      els.collect { |el| new_element(el) }
-    end
-
     def elements
       @element_list ||= []
     end
@@ -252,8 +260,8 @@ module BinData
       element
     end
 
-    def new_element(value = nil)
-      @element_prototype.instantiate(value, self)
+    def new_element
+      @element_prototype.instantiate(nil, self)
     end
 
     def sum_num_bytes_for_all_elements
@@ -275,9 +283,8 @@ module BinData
 
   class ArrayArgProcessor < BaseArgProcessor
     def sanitize_parameters!(obj_class, params) #:nodoc:
-      unless params.has_parameter?(:initial_length) ||
-               params.has_parameter?(:read_until)
-        # ensure one of :initial_length and :read_until exists
+      # ensure one of :initial_length and :read_until exists
+      unless params.has_at_least_one_of?(:initial_length, :read_until)
         params[:initial_length] = 0
       end
 
@@ -286,11 +293,7 @@ module BinData
       params.must_be_integer(:initial_length)
 
       params.merge!(obj_class.dsl_params)
-
-      if params.needs_sanitizing?(:type)
-        el_type, el_params = params[:type]
-        params[:type] = params.create_sanitized_object_prototype(el_type, el_params)
-      end
+      params.sanitize_object_prototype(:type)
     end
   end
 
@@ -300,8 +303,7 @@ module BinData
       loop do
         element = append_new_element
         element.do_read(io)
-        variables = { index: self.length - 1, element: self.last,
-                      array: self }
+        variables = { index: self.length - 1, element: self.last, array: self }
         break if eval_parameter(:read_until, variables)
       end
     end
